@@ -191,7 +191,21 @@ class LambdaToEventbridge(
         :summary: Constructs a new instance of the LambdaToEventbridge class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToEventbridge.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToEventbridgeProps(
@@ -263,13 +277,25 @@ class LambdaToEventbridgeProps:
         :summary: The properties for the LambdaToEventbridge class.
         '''
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToEventbridgeProps.__init__)
+            def stub(
+                *,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
             check_type(argname="argument event_bus_environment_variable_name", value=event_bus_environment_variable_name, expected_type=type_hints["event_bus_environment_variable_name"])
             check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
